# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/love/love_spell/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Love\\LoveSpell\\": "packages/love/love_spell/src",
            "Love\\LoveSpell\\Seeders\\": "packages/love/love_spell/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Love\LoveSpell\Providers\LoveSpellServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'LoveSpell'  => Love\LoveSpell\Facades\LoveSpell::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Love\\LoveSpell\\Seeders\\LoveSpellTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Love\LoveSpell\Providers\LoveSpellServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Love\LoveSpell\Providers\LoveSpellServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Love\LoveSpell\Providers\LoveSpellServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/love_spell/{modulename}

**User**

    http://path-to-route-folder/user/love_spell/{modulename}

**Public**

    http://path-to-route-folder/love_spells


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/love_spell/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/love_spell/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/love_spell/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/love_spell/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/love_spell/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/love_spell/{modulename}/{slug}
    METHOD: GET